@@ -36,6 +36,9 @@ $mail_from = $App->getConfig('MAIL_FROM','benno');
 
 $sessionMailId = $App->getParam('sessionMailId');
 $mailTo = $App->getParam('mailTo');
+if ($App->getConfig('RESEND_MAILTO') == 'last') {
+    $App->setSession('resendMailto',$mailTo);
+}
 
 try {
     $rawMail = $Backend->fetchRaw($archive,$sessionMailId);
