@@ -219,6 +219,7 @@ class Backend
             $this->filter = 'NOT*';
         }
 
+        $query = $Query->getQuery();
         $request_url  = $this->base_url.'/search/';
         list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
         $query_string = 'archive='.$archive .
@@ -227,11 +228,11 @@ class Backend
                  '&start='.$startNum .
                  '&sort='.$Query->getSortField() .
                  '&sortAsc='.$Query->getSortAsc() .
-                 '&query='.$Query->getQuery();
+                 '&query='.$query;
         if ($scid)  $query_string .= '&scid='.$scid;
 
         $App->log("Query string: $query",3,'Backend');
-        $App->log("Filter string: $query",4,'Backend');
+        $App->log("Filter string: $this->filter",4,'Backend');
 
         $resultList = $this->_curl_query($request_url,$query_string);
 
