@@ -178,17 +178,14 @@ class Query
      */
     function getSortField()
     {
-        $sortField = 'Date';
-        if ($this->sort == 'dateAsc') {
+        if ($this->sort) {
+            $sortField = preg_replace('/(.+)(Asc|Desc)$/','$1',$this->sort);
+        }
+        else {
             $sortField = 'Date';
         }
-        elseif ($this->sort == 'subjectAsc') {
-            $sortField = 'Subject';
-        }
-        elseif ($this->sort == 'subjectDesc') {
-            $sortField = 'Subject';
-        }
-        return $sortField;
+
+        return ucfirst($sortField);
     }
 
     /**
@@ -197,15 +194,10 @@ class Query
     function getSortAsc()
     {
         $sortOrder = 'false';
-        if ($this->sort == 'dateAsc') {
-            $sortOrder = 'true';
-        }
-        elseif ($this->sort == 'subjectAsc') {
-            $sortOrder = 'true';
-        }
-        elseif ($this->sort == 'subjectDesc') {
-            $sortOrder = 'false';
+        if (preg_match('/Asc$/',$this->sort)) {
+            $sortOrder = true;
         }
+
         return $sortOrder;
     }
  
